[![DOI](https://zenodo.org/badge/676952944.svg)](https://zenodo.org/record/8392335)



# Frenetix: C++-accelerated Trajectory Planning in a Frenét Frame

A Python library to sample polynomial trajectories in a curvilinear
coordinate system and evaluate them for feasibility and cost.

For background and rationale, see the following paper:
M. Werling, J. Ziegler, S. Kammel and S. Thrun, "Optimal trajectory generation for dynamic street scenarios in a Frenét Frame," 2010 IEEE International Conference on Robotics and Automation, Anchorage, AK, USA, 2010, pp. 987-993, doi: 10.1109/ROBOT.2010.5509799.

